@@ -1,9 +1,8 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 from openpyxl.reader.excel import load_workbook
 from openpyxl.xml.functions import fromstring
-from openpyxl.workbook import Workbook
 
 from ..comments import Comment
 
@@ -40,4 +39,4 @@ def test_comments_with_iterators(datadir):
     wb = load_workbook('comments.xlsx', read_only=True)
     ws = wb['Sheet1']
     with pytest.raises(AttributeError):
-        assert ws.cell(coordinate="A1").comment.author == "Cuke"
+        assert ws["A1"].comment.author == "Cuke"
